import requests
import json
import os

URL = os.getenv("QE_API_SERVER")

def login_ui(server, login_id, login_password):
    response = requests.request("POST", f"http://{URL}/api/login_user/", data={
            'server' : server,
            'username': login_id,
            'password': login_password
        })
    print(json.loads(response.text))
    return json.loads(response.text)


import requests
import json
import os

URL = os.getenv("QE_API_SERVER")

def get_path_value(path):
    response = requests.request("GET", f"http://{URL}/api/vault?path={path}")
    return json.loads(response.text)

def get_key_value(path, key) :
    response = requests.request("GET", f"http://{URL}/api/vault?path={path}&key={key}")
    return json.loads(response.text)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['test_automation']

package_data = \
{'': ['*']}

install_requires = \
['pytest>=7.2.0,<8.0.0', 'requests>=2.28.1,<3.0.0']

setup_kwargs = {
    'name': 'test-automation',
    'version': '0.1.2',
    'description': 'test framework for yogiyo',
    'long_description': 'None',
    'author': 'KimKitaeB',
    'author_email': 'kt.kim@wesang.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
